# instrumentlab

Controlling test instruments like oscilloscopes, power supplies, ...

See https://github.com/mvanriet/instrumentlab/wiki for more information.

# License and Copyright

   Copyright 2024  Marc Van Riet et al.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use the source code in this repository except in compliance
   with the License.

   You may find the full text of the License in the file LICENSE in the root
   of this repository, or you may obtain a copy of the License at
       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   